@@ -589,6 +589,7 @@ class BoundingBox:
             else:
                 self.__tl = self.__c - self.__sz / 2
         return self.__tl
+    tl = top_left
 
     @property
     def bottom_right(self):
@@ -601,6 +602,7 @@ class BoundingBox:
             else:
                 self.__br = self.__c + self.__sz / 2
         return self.__br
+    br = bottom_right
 
     @property
     def size(self):
@@ -629,10 +631,12 @@ class BoundingBox:
     @property
     def bottom_left(self):
         return np.asarray([self.top_left[0], self.bottom_right[1]])
+    bl = bottom_left
 
     @property
     def top_right(self):
         return np.asarray([self.bottom_right[0], self.top_left[1]])
+    tr = top_right
 
     def __getitem__(self, item):
         item = item.lower()
@@ -768,6 +772,20 @@ class BoundingBox:
             return BoundingBox(tl=(xs[0], ys[0]), br=(xs[1], ys[1]))
 
 
+def average_bbox(bboxes):
+    """
+    Computes the average from a set of bboxes
+
+    :param bboxes: Iterable of BBoxes. If empty, returns NaN
+    :return: Average BBox
+    """
+    if len(bboxes):
+        avg = np.mean(np.asarray([bb.extrema for bb in bboxes]), axis=0)
+        return BoundingBox(tl=avg[:2], br=avg[2:])
+    else:
+        return np.NaN
+
+
 def build_line(pts, normalised=True):
     """
     Build a Line from two end-points
@@ -1123,7 +1141,7 @@ class VideoParser:
         # If seeking
         if self.StartAt > 0:
             stream.set(cv2.CAP_PROP_POS_FRAMES, self.StartAt)
-            assert stream.get(cv2.CAP_PROP_POS_FRAMES) == self.StartAt
+            assert stream.get(cv2.CAP_PROP_POS_FRAMES) == self.StartAt, f"Unable to set Start for {self.path}"
 
         # Store/Initialise CV2s properties
         for prop in filter(lambda p: p >=0, self.properties.keys()):
@@ -1171,27 +1189,30 @@ class FrameGetter:
     Note that as per OpenCV defaults, the returned images are always in BGR
     """
 
-    def __init__(self, path, fmt="{:06d}.jpg"):
+    def __init__(self, path, fmt="{:06d}.jpg", offset=0):
         """
         Initialiser
 
         :param path: Path to the extracted frames or the Video File
         :param fmt:  The format mode for the name. If 'Video', then this is treated as a video
+        :param offset: Optional offset to the frame numbering
         """
         if fmt.lower() != "video" and not os.path.isdir(path):
             raise RuntimeError("A Directory must be specified when fmt is not a video.")
         self.Path = path
         self.Fmt = fmt
+        self.__offset = offset
 
     def __getitem__(self, item):
         """
         Retrieve a frame by Number
 
-        :param item: Frame Number. Note that this is translated directly to image name as per the
-               fmt if reading from folder.
+        :param item: Frame Number. Note that this is translated directly to image name (plus any
+                offset) as per the fmt if reading from folder.
         :return: OpenCV Image
         :raises  AssertionError if the frame does not exist
         """
+        item += self.__offset
         if self.Fmt.lower() == "video":
             v = cv2.VideoCapture(self.Path)
             v.set(cv2.CAP_PROP_POS_FRAMES, item)
