@@ -15,8 +15,8 @@ Author: Michael P. J. Camilleri
 
 from matplotlib.colors import LinearSegmentedColormap as lsc
 from scipy.stats import multivariate_normal as mv_norm
+from mpctools.extensions import npext, utils
 from matplotlib import pyplot as plt, axes
-from mpctools.extensions import npext
 import seaborn as sns
 import pandas as pd
 import numpy as np
@@ -36,6 +36,8 @@ def plot_matrix(
     y_rot=0,
     fmt=".2f",
     fs=10,
+    buffer=1.0,
+    hm_args={},
 ):
     """
     Draw Hinton/Heatmap diagram for visualizing a weight matrix.
@@ -63,16 +65,19 @@ def plot_matrix(
                                   whereas it will infer separate minimum/maximum for Heatmaps
                             Float: Only valid for Hinton plots - use this as the maximum weight
                             Tuple/List: (minimum, maximum). Only for Heatmaps.
-    :param show_val:    If True, then show the numerical value on the heatmap/hinton
+    :param show_val:    If True, then show the numerical value on the heatmap/hinton: if a
+                            matrix, then use it as the values to show.
     :param ax:          Axes to plot on
     :param cax: Only relevant when mode is 'heatmap': if not None, specifies a separate  axes for
                 the colour bar. If False, then do not plot a heatmap colour-bar.
     :param x_labels:    Labels for the x-axes.
-    :param y_labels:    Labels for the y-axes - if None, use same as x
+    :param y_labels:    Labels for the y-axes - if 'same', use same as X
     :param x_rot:       Rotation for the X-Axis Labels
     :param y_rot:       Rotation for the Y-Axis Labels
     :param fmt:         Formatting String for Value labels (if any)
-    :param fs: Font-Size
+    :param fs:          Font-Size
+    :param buffer:      Buffer around the Hinton plot
+    :param hm_args:    Any further arguments to pass to seaborn heatmap
     :return:
     """
     # Sort out the mode
@@ -123,7 +128,17 @@ def plot_matrix(
                     edgecolor="white" if w > 0 else "black",
                 )
             )
-            if show_val:
+            if isinstance(show_val, np.ndarray):
+                ax.text(
+                    x,
+                    y,
+                    show_val[y, x],
+                    horizontalalignment="center",
+                    verticalalignment="center",
+                    color="black" if w > 0 else "white",
+                    fontsize=fs,
+                )
+            elif isinstance(show_val, bool) and show_val:
                 ax.text(
                     x,
                     y,
@@ -133,8 +148,9 @@ def plot_matrix(
                     color="black" if w > 0 else "white",
                     fontsize=fs,
                 )
-        ax.set_ylim(-1, matrix.shape[0])
-        ax.set_xlim(-1, matrix.shape[1])
+
+        ax.set_ylim(-buffer, matrix.shape[0] -1 + buffer)
+        ax.set_xlim(-buffer, matrix.shape[1] -1 + buffer)
         ax.invert_yaxis()
     elif mode == 'heatmap':
         sns.heatmap(
@@ -147,6 +163,7 @@ def plot_matrix(
             cbar=cax is not False,
             cbar_ax=cax if isinstance(cax, axes.Axes) else None,
             annot_kws={"size": fs},
+            **hm_args
         )
     else:
         sns.heatmap(
@@ -180,6 +197,27 @@ def plot_matrix(
         )
 
 
+def autolabel_bar(bars, labels=None, fs=12, prec=3, ax=None):
+    """
+    Add a Text-Label to the top of each bar in a bar-chart.
+
+    :param bars:  Rectangles returned by plot.bar()
+    :param labels: Alternative labels to override with
+    :param fs: Fontsize for text
+    :param ax:     Axes on which to plot.
+    """
+    ax = utils.default(ax, plt.gca())
+    for i, b in enumerate(bars):
+        ax.annotate(
+            f'{b.get_height():.{prec}f}' if labels is None else labels[i],
+            xy=(b.get_x() + b.get_width() / 2, b.get_height()),
+            xytext=(0, 5),
+            textcoords="offset points",
+            ha='center', va='bottom',
+            fontsize=fs,
+        )
+
+
 def plot_blandaltman(
     series1, series2, mode, labels, model_names, fnt_size=15, ax=None, *args, **kwargs
 ):
